import AHFpy
import numpy as np
import matplotlib.pyplot as plt

## Test for AHF on GRAthena++ data file for collapse test

## In principle this works and is tested with VC data. However, it should work with CC data provided 
## that: 1. "ghost_zones" parameter is not set; 2. "num_ghost" is set to 0; 3. The full grid is given
## (not the octant) and consequently "data_sym" is not set. If these conditions are met, the reading
## script of Athena should exactly be the same as the original one.


## The file "collapse_GRAthena/gr_tov_collapse.out6.00004.athdf" has been generated with the following 
## features:
## - Octant symmetry
## - 4 refinement levels (from 0 (coarser) to 3 (finest))
## - MeshBlocks of 16**3 points
## - Mesh of 32**3 points
## - 4 ghosts (this parameter is required)
## - "ghost_zones" active in the parfile (this setting is required)

ahf = AHFpy.AHF.AHF(initial_radius = [2.], central_points = [(0.,0.,0.)])

## Use initial guess for the radius to automatically restrict data in GRAthena++ and be able to 
## make use of the finest reflev
## Use an initial radius that is a bit bigger than the initial guess, say at least 2 times bigger

ath_reader_opts = {'num_ghost':4, 'initial_radius':2.*2}
ahf.run(["collapse_GRAthena/gr_tov_collapse.out6.00004.athdf"],
        input_data_from = 'HDF5_athena',
        data_sym = "octant",
        data_options = ath_reader_opts)

## Choose a coarser reflev to be able to store all 3D arrays in the ram

# Test with data at level 2
#ahf = AHFpy.AHF.AHF(initial_radius = [2.], central_points = [(0.,0.,0.)])
#ahf.run(["collapse_GRAthena/gr_tov_collapse.out6.00004.athdf"], input_data_from = 'HDF5_athena', data_sym = "octant", num_ghost = 4, level = 2)

# Test with data at level 1
#ahf = AHFpy.AHF.AHF(initial_radius = [2.], central_points = [(0.,0.,0.)])
#ahf.run(["collapse_GRAthena/gr_tov_collapse.out6.00004.athdf"], input_data_from = 'HDF5_athena', data_sym = "octant", num_ghost = 4, level = 1)

# Test with data at level 0
#ahf = AHFpy.AHF.AHF(initial_radius = [2.], central_points = [(0.,0.,0.)])
#ahf.run(["collapse_GRAthena/gr_tov_collapse.out6.00004.athdf"], input_data_from = 'HDF5_athena', data_sym = "octant", num_ghost = 4, level = 0)

