# Test AHF with Kerr Cartesian data

import sys, os
import numpy as np
import matplotlib.pyplot as plt

if 'AHFpy' in sys.modules:
    from AHFpy import AHF
    from AHFpy.Puncture import Puncture
else:
    sys.path.insert(0, os.path.abspath('../AHFpy'))
    from AHF import AHF
    from Kerr import Kerr

# Generate Kerr data with a=0.0
# -----------------------------

dfile = "data/kerr_a00.h5"

M = 1.0
h = M/32.
xx = np.arange(-2*M+h*M/2,2*M,h*M)
p = Kerr(M=M, x = xx, y = xx, z = xx)
p.Output(dfile)

# Search for the horizon
# ----------------------

outputdir = os.path.basename(sys.argv[0]).split('.')[0]

nphi, ntheta = 16, 8
ahf = AHF(lmax = 1, mass_tol = 1e-4,
          glgrid = True,  nphi = nphi, ntheta = ntheta,
          #glgrid = False, nphi = nphi, ntheta = ntheta,
          initial_radius = [1.0],
          output_modes = True,
          output_surface = True,          
          outputdir = outputdir)
ahf.run([dfile])

# Horizon surface plot
# --------------------

x,y,z = np.loadtxt('test_AHF_Kerr_a00/horizon00_surface.txt',unpack=True)

fig = plt.figure()
ax = fig.add_subplot(projection='3d')
ax.plot_surface(x.reshape(nphi,ntheta), y.reshape(nphi,ntheta), z.reshape(nphi,ntheta), alpha=0.8)
plt.show()
