# Test AHF with Kerr Cartesian data

import sys, os
import numpy as np
import matplotlib.pyplot as plt

if 'AHFpy' in sys.modules:
    from AHFpy import AHF
    from AHFpy.Puncture import Puncture
else:
    sys.path.insert(0, os.path.abspath('../AHFpy'))
    from AHF import AHF
    from Kerr import Kerr

# Generate Kerr data with a=0.9
# -----------------------------

dfile = "data/kerr_a09.h5"

M = 1.0
a = 0.9

#h = M/16.
h = M/32
#h = M/64.
xx = np.arange(-2*M+h*M/2,2*M,h*M)
z = np.arange(-h*M/2,2*M,h*M) # bitant
p = Kerr(M=M, a=a, x = xx, y = xx, z = z)
p.Output(dfile)

# Search for the horizon
# ----------------------

outputdir = os.path.basename(sys.argv[0]).split('.')[0]

nphi, ntheta = 16,8
ahf = AHF(lmax = 8, mass_tol = 1e-4, hmean_tol = 100,
          glgrid = True, nphi = nphi, ntheta = ntheta,
          #glgrid = False, nphi = nphi, ntheta = ntheta,
          initial_radius = [1.0],
          output_modes = True,
          output_surface = True,
          outputdir = outputdir)
ahf.run([dfile], data_sym = "bitant")

rb = np.sqrt(M*2 - a**2) * 0.5
#rr = M + rb + 0.25*(M**2 - a**2)/(4.0*rb)
print('Exact rb = {}'.format(rb))

# Horizon surface plot
# --------------------

x,y,z = np.loadtxt('test_AHF_Kerr_a09/horizon00_surface.txt',unpack=True)

r = np.sqrt(x**2+y**2+z**2)
print('rmin = {:.6e} rmax = {:.6e}'.format(r.min(),r.max()))

fig = plt.figure()
ax = fig.add_subplot(projection='3d')
ax.plot_surface(x.reshape(nphi,ntheta), y.reshape(nphi,ntheta), z.reshape(nphi,ntheta), alpha=0.8)
plt.show()
