# Test AHF with Puncture data

import sys, os
import numpy as np
import matplotlib.pyplot as plt

if 'AHFpy' in sys.modules:
    from AHFpy import AHF
    from AHFpy.Puncture import Puncture
else:
    sys.path.insert(0, os.path.abspath('../AHFpy'))
    from AHF import AHF
    from Puncture import Puncture

# Generate puncture data
# ----------------------

dfile = "data/puncture_m100.h5"

M = 1.0
h = M/8.
xx = np.arange(-4*M+h*M/2,4*M,h*M)
p = Puncture(M=M, x = xx, y = xx, z = xx)
p.Output(dfile)

# Search for the horizon
# ----------------------

outputdir = os.path.basename(sys.argv[0]).split('.')[0]

ahf = AHF(lmax = 4, mass_tol = 1e-4,
          glgrid = True, nphi = 8, ntheta = 4,
          #glgrid = True, nphi = 16, ntheta = 8,
          #glgrid = False, nphi = 10, ntheta = 20,
          initial_radius = [1.0],
          output_modes = True,
          outputdir = outputdir)
ahf.run([dfile])

# Check coefficients
# ------------------

clm = np.loadtxt(os.path.join(outputdir,'horizon00_modes.txt'),
                 dtype = np.complex128)

xlm = []
for l in np.arange(0,ahf.lmax+1):
    for m in np.arange(0,l+1):
        xlm.append('{}{}'.format(str(l),str(m)))

fig, ax = plt.subplots()
ax.semilogy(xlm,np.abs(clm.real),'o', markerfacecolor="None", label='Real')
ax.semilogy(xlm,np.abs(clm.imag),'x', label='Imag')
ax.set(xlabel=r'$(\ell,m)$', ylabel=r'$|c_{\ell m}|$',
       title=r'$\ell_\max={}$ $n_\theta={}$ $n_\phi={}$ (GL grid? {})'.format(ahf.lmax,ahf.ntheta,ahf.nphi,ahf.glgrid))
ax.grid()
ax.legend()
fig.savefig(os.path.join(outputdir,'coefficients.png'))
plt.show()
