#!/usr/bin/env python

from setuptools import setup, find_packages
from distutils.extension import Extension
import numpy

try:
    from Cython.Distutils import build_ext
except ImportError:
    use_cython = False
else:
    use_cython = True

cmdclass = {}
ext_modules = []
if use_cython:
    ext_modules += [
        Extension("AHFpy.interp_3d", ["AHFpy/interp_3d.pyx"], include_dirs=[numpy.get_include()]),
    ]
    cmdclass.update({'build_ext': build_ext})
else:
    ext_modules += [
        Extension("AHFpy.interp_3d", ["AHFpy/interp_3d.c"]),
    ]


    
setup(
    name='AHFpy',
    version='1.0.0',
    description='Apparent Horizon Finder in Python',
    author='SB',
    author_email='sebastiano.bernuzzi@uni-jena.de',
    url = 'https://git.tpi.uni-jena.de/sbernuzzi/ahfpy',
    packages = find_packages(),
    requires = ['h5py', 'numpy', 'scipy', 'matplotlib'],
    cmdclass = cmdclass,
    ext_modules = ext_modules, include_dirs=[numpy.get_include()]
)
